local mod = ...



-- Building Progress List: -------------------------------------------------------------------------------------
mod:override({
    Id = "DEFAULT_BALANCING",
    BuildingProgressList = {
        Action = "APPEND",
        "BUILDING_PROGRESS_LIST_FUEL"
    }
})

mod:register({
    DataType = "BUILDING_PROGRESS_LIST",
    Id = "BUILDING_PROGRESS_LIST_FUEL",
    ProgressList = {
        {
            UnlockName = "UNLOCK_FUELMONGER",
            AssetBuildingList = {
                "FUELCART",
            },
            IsManuallyUnlocked = true,
            VillagerRequired = {
                Status = "NEWCOMER",
                Quantity = 8
            }
        },
    },
})



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------

mod:override({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        "EVENT_FUEL_START",
    }
})



-- Event: Start ---------------------------------------------------------------------------------------------

mod:register({
	DataType = "EVENT",
    Id = "EVENT_FUEL_START",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysBetweenOccurences = nil,
    DaysToFirst = 1,
    Delay = 10, 
	ConditionList = {
		{
            DataType = "EVENT_CONDITION_BUILDING_BUILT",
            AssetBuilding = "MONUMENT_MARKET"
		}
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_FUEL_UNLOCK"
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_FUEL_START"
        },
    }
})



-- Quest: Fuelmonger unlock ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_FUEL_UNLOCK",
    Name = "QUEST_FUEL_UNLOCK_NAME",
    Description = "QUEST_FUEL_UNLOCK_DESC",
    IsSilent = true,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_BUILD", 
        BuildingListToBuild = {
            "MONUMENT_MARKET"
        }
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_UNLOCK_BUILDING_LIST",
            UnlockName = "UNLOCK_FUELMONGER"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Quest: Build and staff ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_FUEL_START",
    Name = "QUEST_FUEL_START_NAME",
    Description = "QUEST_FUEL_START_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_CONTAINER", 
        QuestContainerDescription = "QUEST_FUEL_START_NAME",
        SubQuestList = {
            {
                DataType = "QUEST_FUNCTION_BUILD", 
                BuildingListToBuild = {
                    "FUELCART"
                }
            },
            {
                DataType = "QUEST_FUNCTION_ASSIGN_RESOURCE_MARKET",
                Resource = "RESOURCE_WOOD_SELL"
                -- Resource = "WOOD"
            },
            {
                DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
                Job = "FUELSELLER_JOB"
            },
        }
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_RESOURCES",
            ResourceCollection = {
                {
                    Resource = "WOOD",
                    Quantity = 50
                }
            }
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

